AnimatedShape class

Render an animated widget based on the animation type given and with a given child widget

Inheritance

Constructors

AnimatedShape({required Widget shape, ANIMATION_TYPE animationType = ANIMATION_TYPE.NONE, double animationValue = 1, Animation<Offset>? animationOffset, AnimationController? animationController})

Properties

animationController → AnimationController?
Animation controller used if the animationType equal ANIMATION_TYPE.ROTATE
final
animationOffset → Animation<Offset>?
Animation offset used if the animationType equal ANIMATION_TYPE.SLIDE_VERTICALLY
final
animationType → ANIMATION_TYPE
aimation that will be set when navigating between navigation bar items possible values
final
animationValue → double
Animation value used as an opacity if the animation is ANIMATION_TYPE.FADE
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → Widget
the shape child that will be wraped with the animated widget
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited